********************************************************************************
* This file collects functions for the creation of visualisation scripts
* in grads script.
* TODO: to be extended
*******************************************************************************

      SUBROUTINE openSimpleGS (p_fileId, p_fileName,p_bgName,p_varName)
************************************************************************
* Opens a normal grads script file with grads logo and axes turned off and the
* passed in self-describing netcdf file as background.
*
* Input:
*  - p_fileId (Integer): the unit number of the file
*  - p_fileName (String): the name of the new file (the grads script file extension
*	".gs" is automatically appended to the name!)
*  - p_bgName (String): a self-describing NetCDF file for the background (full file name)
*  - p_varName (String): the name of the variable in the NetCDF file to be displayed
************************************************************************
 
*     Functions from the function library
      INTEGER strlen

*     Parameters
      INTEGER p_fileId
      CHARACTER*(*) p_fileName, p_bgName, p_varName

*     Vars
      CHARACTER fileName*100, bgName*100, varName*20
      fileName = p_fileName
      bgName = p_bgName
      varName=p_varName

*     Open grads script file to be written
      OPEN(p_fileId,
     c file=fileName(1:strlen(fileName)) // ".gs" )

      WRITE (p_fileId, *) "say 'Autogenerated GradsScript File'"
      WRITE (p_fileId, *) "say 'Opening the background'"
      WRITE (p_fileId, *) "'sdfopen " // bgName(1:strlen(bgName)) // "'"
*     Shaded background style
      WRITE (p_fileId, *) "'set gxout shaded'"
      WRITE (p_fileId, *) "'c'"
      WRITE (p_fileId, *) "'set xlab off'"
      WRITE (p_fileId, *) "'set ylab off'"
      WRITE (p_fileId, *) "'set grads off'"
      if (strlen(varName) > 0)
     c    WRITE (p_fileId, *) "'d ", varName(1:strlen(varName)) , "'"
            
      END

   
      SUBROUTINE drawGSPt (p_fileId, p_lat, p_lon, p_size, 
     c      p_style, p_label)   
************************************************************************
* Writes the code into the grads script file for drawing a marker point 
* on the NetCDF background.
*  
* Input:
*  - p_fileId (Integer): the unit number of the grads script file
*  - p_lat (Real): the latitude of the point to be drawn
*  - p_lon (Real): the longitude of the point to be drawn
*  - p_size (Real): the size of the point (for coordinate locations 0.1 is
*	 normally small, 0.3 medium, 0.5 big)
*  - p_style (Integer): which style the marker should have, available:
*       1 = cross,
*       2 = open circle
*       3 = closed circle
*       4 = open square
*       5 = closed square
*       6 = X
*       7 = diamond
*       8 = triangle
*       9 = none
*      10 = open circle with vertical line
*      11 = open oval
*  - p_label (String): if anything but "" is passed in, this label is written
*	 next to the marker point
************************************************************************

      INTEGER p_fileId, p_style, strlen
      REAL p_lat, p_lon, p_size !params
      CHARACTER p_label*(*), label*50
      label = p_label
      
       WRITE (p_fileId, *) ""
       WRITE (p_fileId, *) "'q ll2xy", p_lon, p_lat, "'"
       WRITE (p_fileId, *) "xco = subwrd(result,1)"
       WRITE (p_fileId, *) "yco = subwrd(result,2)"
       WRITE (p_fileId, *) "'draw mark ",p_style,
     c                     " ' xco ' ' yco '", p_size, "'"
       if (strlen(label) > 0) 
     c  WRITE (p_fileId, *) "'draw string ' xco+0.2 ' ' yco-0.1 ' " // 
     c     label(1:strlen(label)) // "'"
      
      END
      

      SUBROUTINE closeSimpleGS (p_fileId, p_fileName)
************************************************************************
* Finishes (i.e. writes command for GrADS meta file output) and closes 
* the open grads script file.
*
* Input:
*  - p_fileId (Integer): the unit number of the file
*  - p_fileName (String): the name of the script output file (the grads metafile 
* 	extension ".gds" is automatically appended to the name!)
************************************************************************

      
*     Functions from the function library
      INTEGER strlen

*     Parameters
      INTEGER p_fileId
      CHARACTER p_fileName*(*)

*     Vars
      CHARACTER fileName*100
      fileName = p_fileName
      fileName = fileName(1:strlen(fileName)) // '.gds'
      
      WRITE (p_fileId, *) "'enable print ",
     c      fileName(1:strlen(fileName)),"'"
      WRITE (p_fileId, *) "'print'"
      WRITE (p_fileId, *) "'disable print'"
      WRITE (p_fileId, *) "'quit'"
      
      CLOSE(p_fileId)
      END
